package com.ruoyi.project.sems.his.service.impl;

import java.util.List;

import com.ruoyi.project.sems.domain.TSpecdevDt;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.sems.his.mapper.TSpechiDtMapper;
import com.ruoyi.project.sems.his.domain.TSpechiDt;
import com.ruoyi.project.sems.his.service.ITSpechiDtService;

/**
 * 特种设备电梯台账历史Service业务层处理
 *
 * @author ruoyi
 * @date 2021-09-02
 */
@Service("tSpechiDtService")
public class TSpechiDtServiceImpl implements ITSpechiDtService
{
    @Autowired
    private TSpechiDtMapper tSpechiDtMapper;

    /**
     * 查询特种设备电梯台账历史
     *
     * @param id 特种设备电梯台账历史ID
     * @return 特种设备电梯台账历史
     */
    @Override
    public TSpechiDt selectTSpechiDtById(Long id)
    {
        return tSpechiDtMapper.selectTSpechiDtById(id);
    }

    /**
     * 查询特种设备电梯台账历史列表
     *
     * @param tSpechiDt 特种设备电梯台账历史
     * @return 特种设备电梯台账历史
     */
    @Override
    public List<TSpechiDt> selectTSpechiDtList(TSpechiDt tSpechiDt)
    {
        return tSpechiDtMapper.selectTSpechiDtList(tSpechiDt);
    }

    /**
     * 新增特种设备电梯台账历史
     *
     * @param tSpechiDt 特种设备电梯台账历史
     * @return 结果
     */
    @Override
    public int insertTSpechiDt(TSpechiDt tSpechiDt)
    {
        return tSpechiDtMapper.insertTSpechiDt(tSpechiDt);
    }

    @Override
    public int insertTSpechiDtWithDev(TSpecdevDt tSpecdevDt) {
        return tSpechiDtMapper.insertTSpechiDtByDev(tSpecdevDt);
    }

    /**
     * 修改特种设备电梯台账历史
     *
     * @param tSpechiDt 特种设备电梯台账历史
     * @return 结果
     */
    @Override
    public int updateTSpechiDt(TSpechiDt tSpechiDt)
    {
        return tSpechiDtMapper.updateTSpechiDt(tSpechiDt);
    }

    /**
     * 批量删除特种设备电梯台账历史
     *
     * @param ids 需要删除的特种设备电梯台账历史ID
     * @return 结果
     */
    @Override
    public int deleteTSpechiDtByIds(Long[] ids)
    {
        return tSpechiDtMapper.deleteTSpechiDtByIds(ids);
    }

    /**
     * 删除特种设备电梯台账历史信息
     *
     * @param id 特种设备电梯台账历史ID
     * @return 结果
     */
    @Override
    public int deleteTSpechiDtById(Long id)
    {
        return tSpechiDtMapper.deleteTSpechiDtById(id);
    }

    @Override
    public List<TSpechiDt> selectTSpechiDtByReform(Long devId) {
        return tSpechiDtMapper.selectTSpechiDtByReform(devId);
    }

    /**
     * 通过devId删除修改记录
     * @param devId
     * @return
     */
    @Override
    public int deleteTSpechiDtByDevId(Long devId) {
        return tSpechiDtMapper.deleteTSpechiDtByDevId(devId);
    }
}
